# -*- coding: utf-8 -*-
"""
Created on Thu Jul  2 16:57:59 2015

@author: sergey
"""

import scipy.stats as stats
from IPython.core.pylabtools import figsize
import numpy as np
import matplotlib.pyplot as plt
import pymc as pm

from matplotlib import rc
 
font = {'family': 'Verdana',
        'weight': 'normal'}
rc('font', **font)

figsize(10, 6)


data = np.loadtxt("mixture_data.csv", delimiter=",")

plt.hist(data, bins=20, color="k", histtype="stepfilled", alpha=0.8)
plt.title("Гистограмма данных")
plt.ylim([0, None])
print(data[:10], "...")

plt.figure()

p = pm.Uniform("p", 0, 1)

assignment = pm.Bernoulli("assignment", 1-p, size = data.shape[0])
taus = 1.0 / pm.Uniform("s", 0, 100, size=2) ** 2
centers = pm.Normal("c", [120, 190], [0.01, 0.01], size=2)

"""
Следующие две детерминированные функции (переменные) строят массивы центров
и тау для каждой точки данных соответственно её предполагаемой принадлежности
кластеру (assignment).
"""

@pm.deterministic
def center_i(assignment=assignment, centers=centers):
    return centers[assignment.astype(int)]

@pm.deterministic
def tau_i(assignment=assignment, taus=taus):
    return taus[assignment.astype(int)]

print("Случайная принадлежность кластеру: ", assignment.value.astype(int)[:5], "...")
print("Назначенные центры: ", center_i.value[:5], "...")
print("Назначенная точность: ", tau_i.value[:5], "...")

# Добавляем наблюдения
observations = pm.Normal("obs", center_i, tau_i, value=data, observed=True)

model = pm.Model([p, assignment, center_i, tau_i, observations, taus, centers])

#m = pm.MAP(model)
#m.fit()

mcmc = pm.MCMC(model)
mcmc.sample(50000)

plt.subplot(311)
lw = 1
center_trace = mcmc.trace("c")[:]

# Настройки цветов
colors = ["#348ABD", "#A60628"] \
if center_trace[-1, 0] > center_trace[-1, 1] \
    else ["#A60628", "#348ABD"]

plt.plot(center_trace[:, 0], label="след центра 0", c=colors[0], lw=lw)
plt.plot(center_trace[:, 1], label="след центра 1", c=colors[1], lw=lw)
plt.title("Следы неизвестных параметров")
leg = plt.legend(loc="upper right")
leg.get_frame().set_alpha(0.7)

plt.subplot(312)
std_trace = mcmc.trace("s")[:]
plt.plot(std_trace[:, 0], label="След дисперсии кластера 0",
     c=colors[0], lw=lw)
plt.plot(std_trace[:, 1], label="След дисперсии кластера 1",
     c=colors[1], lw=lw)
plt.legend(loc="upper left")

plt.subplot(313)
p_trace = mcmc.trace("p")[:]
plt.plot(p_trace, label="$p$: Частота принадлежности кластеру 0",
     color="#467821", lw=lw)
plt.xlabel("Шаги")
plt.ylim(0, 1)
plt.legend()
