# -*- coding: utf-8 -*-

from IPython.core.pylabtools import figsize
import matplotlib.pyplot as plt
import numpy as np
import pymc as pm
from matplotlib import rc
 
font = {'family': 'Verdana',
        'weight': 'normal'}
rc('font', **font)



figsize(10, 4)


x_t = pm.rnormal(0, 1, 200)
x_t[0] = 0
y_t = np.zeros(200)
for i in range(1, 200):
    y_t[i] = pm.rnormal(y_t[i - 1], 1)

plt.plot(y_t, label="$y_t$", lw=3)
plt.plot(x_t, label="$x_t$", lw=3)
plt.xlabel("Время, $t$")
plt.legend()

def autocorr(x):
    result = np.correlate(x, x, mode='full')
    result = result / np.max(result)
    return result[result.size / 2:]

plt.figure()

colors = ["#348ABD", "#A60628", "#7A68A6"]

x = np.arange(1, 200)
plt.bar(x, autocorr(y_t)[1:], width=1, label="$y_t$",
        edgecolor=colors[0], color=colors[0])
plt.bar(x, autocorr(x_t)[1:], width=1, label="$x_t$",
        color=colors[1], edgecolor=colors[1])

plt.legend(title="Автокорреляция")
plt.ylabel("Измеренная автокорреляция \nмежду $y_t$ и $y_{t-k}$.")
plt.xlabel("k (задержка)")
plt.title("График автокорреляции $y_t$ и $x_t$ для разных задержек $k$.")

plt.figure()

max_x = 200 // 3 + 1
x = np.arange(1, max_x)

plt.bar(x, autocorr(y_t)[1:max_x], edgecolor=colors[0],
        label="без прореживания", color=colors[0], width=1)
plt.bar(x, autocorr(y_t[::2])[1:max_x], edgecolor=colors[1],
        label="каждый второй пример", color=colors[1], width=1)
plt.bar(x, autocorr(y_t[::3])[1:max_x], width=1, edgecolor=colors[2],
        label="каждый третий пример", color=colors[2])

plt.autoscale(tight=True)
plt.legend(title="График автокорреляции $y_t$", loc="lower left")
plt.ylabel("Измеренная автокорреляция \nмежду $y_t$ и $y_{t-k}$.")
plt.xlabel("k (задержка)")
plt.title("Влияние прореживания на автокорреляцию $y_t$ с разными задержками $k$.")