# -*- coding: utf-8 -*-
import numpy as np
import pymc as pm
from matplotlib import pyplot as plt
from IPython.core.pylabtools import figsize
from pymc.Matplot import plot as mcplot

from matplotlib import rc
 
font = {'family': 'Verdana',
        'weight': 'normal'}
rc('font', **font)

figsize(13, 6)


N = 100
p = pm.Uniform("freq_cheating", 0, 1)

true_answers = pm.Bernoulli("truths", p, size=N)

first_coin_flips = pm.Bernoulli("first_flips", 0.5, size=N)
print("Бросок первой монеты: ", first_coin_flips.value)

second_coin_flips = pm.Bernoulli("second_flips", 0.5, size=N)

@pm.deterministic
def observed_proportion(t_a=true_answers,
                        fc=first_coin_flips,
                        sc=second_coin_flips):

    observed = np.logical_or(np.logical_and(fc, t_a), np.logical_and(~fc, sc))
    return observed.sum() / float(N)
    
    
D = 35

observations = pm.Binomial("obs", N, observed_proportion, observed=True,
                           value=D)
                           
model = pm.Model([p, true_answers, first_coin_flips,
                  second_coin_flips, observed_proportion, observations])

mcmc = pm.MCMC(model)
mcmc.sample(60000, 30000)

mcplot(mcmc.trace("freq_cheating"), common_scale=False)

plt.figure()

p_trace = mcmc.trace("freq_cheating")[:]
plt.hist(p_trace, histtype="stepfilled", normed=True, alpha=0.85, bins=30,
         label="Апостериорное распределение", color="#348ABD")
plt.xlim(0, 1)
plt.legend();
    