# -*- coding: utf-8 -*-
from IPython.core.pylabtools import figsize
import pymc as pm
from matplotlib import pyplot as plt
from pymc.Matplot import plot as mcplot

from matplotlib import rc
 
font = {'family': 'Verdana',
        'weight': 'normal'}
rc('font', **font)

figsize(13, 6)


N = 100
D = 35

p = pm.Uniform("freq_cheating", 0, 1)


@pm.deterministic
def p_skewed(p=p):
    return 0.5 * p + 0.25
    
yes_responses = pm.Binomial("number_cheaters", 100, p_skewed,
                            value=D, observed=True)
                            
model = pm.Model([yes_responses, p_skewed, p])


mcmc = pm.MCMC(model)
mcmc.sample(25000, 2500)

mcplot(mcmc.trace("freq_cheating"), common_scale=False)

plt.figure()


p_trace = mcmc.trace("freq_cheating")[:]
plt.hist(p_trace, histtype="stepfilled", normed=True, alpha=0.85, bins=30,
         label="Апостериорное распределение", color="#348ABD")
plt.xlim(0, 1)
plt.legend();
    